%global src_dir src/%{name}

Name:		unetbootin
Version:	700
Release:	%mkrel 2
Summary:	Create bootable Live USB drives for a variety of Linux distributions
Group:		File tools
License:	GPLv2+
URL:		http://unetbootin.github.io
Source0:	https://github.com/%{name}/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	net.sourceforge.%{name}.policy
# Syslinux is only available on x86 architectures
ExclusiveArch:	%{ix86} x86_64

BuildRequires:	desktop-file-utils
BuildRequires:	qttools5
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Widgets)

# Not picked up automatically, required for operation
Requires:	extlinux
Requires:	p7zip
Requires:	syslinux
Requires:	polkit

%description
UNetbootin allows you to create bootable Live USB drives for a variety of
Linux distributions from Windows or Linux, without requiring you to burn a CD.
You can either let it download one of the many distributions supported
out-of-the-box for you, or supply your own Linux .iso file if you've already
downloaded one or your preferred distribution isn't on the list.


%prep
%setup -q
cd %{src_dir}

# fix for "libpng warning: iCCP: known incorrect sRGB profile"
find . -type f -name "*.png" -exec convert {} -strip {} \;

%build
cd %{src_dir}
mv unetbootin.desktop mageia-unetbootin.desktop
%{_qt5_bindir}/lupdate unetbootin.pro
%{_qt5_bindir}/lrelease unetbootin.pro
%qmake_qt5

%make_build

%install
cd %{src_dir}
install -D -p -m 0755 %{name} %{buildroot}%{_libexecdir}/%{name}

# Install desktop file
desktop-file-install --vendor="" \
	--remove-key=Version \
	--remove-key=Name[en_US] \
	--remove-key=GenericName[en_US] \
	--remove-key=Comment[en_US] \
	--remove-category=Application \
	--set-key=Exec --set-value=%{name} \
	--dir=%{buildroot}%{_datadir}/applications \
	mageia-unetbootin.desktop

# Install localization files
install -d %{buildroot}%{_datadir}/unetbootin
install -c -p -m 644 unetbootin_*.qm %{buildroot}%{_datadir}/unetbootin/

# Install icons
install -D -c -p -m 644 unetbootin_16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_22.png %{buildroot}%{_datadir}/icons/hicolor/22x22/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_24.png %{buildroot}%{_datadir}/icons/hicolor/24x24/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_192.png %{buildroot}%{_datadir}/icons/hicolor/192x192/apps/unetbootin.png
install -D -c -p -m 644 unetbootin_256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/unetbootin.png

# Policy Kit support for nice root access
%__mkdir_p %{buildroot}%{_bindir}
cat >%{buildroot}%{_bindir}/%{name} <<EOF
#!/bin/sh
if  [[ "\$UID" != "0" ]] ; then
    %{_bindir}/pkexec %{_libexecdir}/%{name} "\$@"
    exit \$?
fi
exec %{_libexecdir}/%{name} "\$@"
EOF
%__install -m 0644 %{SOURCE1} -D %{buildroot}%{_datadir}/polkit-1/actions/net.sourceforge.%{name}.policy


%files
%doc %{src_dir}/readme.md
%attr(0755,root,root) %{_bindir}/%{name}
%{_libexecdir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/applications/mageia-%{name}.desktop
%{_datadir}/icons/hicolor/*/*


%changelog
* Thu Dec 17 2020 umeabot <umeabot> 700-2.mga8
+ Revision: 1660123
- Rebuild for new Qt5

* Wed Nov 25 2020 shlomif <shlomif> 700-1.mga8
+ Revision: 1649148
- New version 700

* Tue Sep 08 2020 shlomif <shlomif> 681-1.mga8
+ Revision: 1623441
- New version 681

* Wed Feb 19 2020 umeabot <umeabot> 677-2.mga8
+ Revision: 1543938
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 shlomif <shlomif> 677-1.mga8
+ Revision: 1482476
- New version 677

* Mon Dec 09 2019 daviddavid <daviddavid> 675-1.mga8
+ Revision: 1465425
- new version: 675
- port to Qt5
- add gentoo patch to port to Qt5
- remove previous hack "export QT_X11_NO_MITSHM=1"

* Mon Dec 09 2019 daviddavid <daviddavid> 661-3.mga8
+ Revision: 1465326
- fix empty Qt GUI window with "export QT_X11_NO_MITSHM=1"
- fix for "libpng warning: iCCP: known incorrect sRGB profile"

* Sun Sep 23 2018 umeabot <umeabot> 661-2.mga7
+ Revision: 1301518
- Mageia 7 Mass Rebuild

* Sat Jun 02 2018 shlomif <shlomif> 661-1.mga7
+ Revision: 1233649
- New version 661

* Fri Dec 08 2017 shlomif <shlomif> 657-1.mga7
+ Revision: 1181717
- New version 657

* Tue May 24 2016 yuri_myasoedov <yuri_myasoedov> 625-1.mga6
+ Revision: 1018201
- remove old tarball unetbootin-619.tar.gz.
- update to new version 625.

* Wed May 04 2016 tv <tv> 619-2.mga6
+ Revision: 1009061
- use %%qmake_qt4
- fix doble exec (at least when already being root)
  (regular user case is still broken)

* Thu Apr 28 2016 shlomif <shlomif> 619-1.mga6
+ Revision: 1007201
- New version 619

* Fri Feb 19 2016 umeabot <umeabot> 613-2.mga6
+ Revision: 969064
- Mageia 6 Mass Rebuild

* Wed Aug 05 2015 sander85 <sander85> 613-1.mga6
+ Revision: 861284
- New version: 613

* Wed Jun 04 2014 sander85 <sander85> 0-5.608.mga5
+ Revision: 633126
- New release

* Sun Oct 13 2013 colin <colin> 0-5.585.mga4
+ Revision: 496226
- Switch to polkit for root authorisation

* Wed Aug 14 2013 sander85 <sander85> 0-4.585.mga4
+ Revision: 466517
- New release: 585

* Wed Jan 23 2013 sander85 <sander85> 0-4.583.mga3
+ Revision: 391377
- Change group

* Wed Jan 23 2013 fwang <fwang> 0-3.583.mga3
+ Revision: 391344
- update rpm group

* Sun Jan 06 2013 sander85 <sander85> 0-2.583.mga3
+ Revision: 339930
- New release: 583

* Tue Sep 18 2012 sander85 <sander85> 0-2.581.mga3
+ Revision: 295942
- New release: 581

* Mon Jul 23 2012 sander85 <sander85> 0-2.578.mga3
+ Revision: 273726
- new release: 578

* Sat Mar 03 2012 sander85 <sander85> 0-2.568.mga2
+ Revision: 217224
- new version

* Sat Jan 07 2012 sander85 <sander85> 0-2.563.mga2
+ Revision: 193008
- new release: 563

* Fri Oct 07 2011 sander85 <sander85> 0-2.555.mga2
+ Revision: 152719
- add extlinux as a requirement as it was splitted from syslinux

* Thu Oct 06 2011 sander85 <sander85> 0-1.555.mga2
+ Revision: 152211
- switch to tarball source

* Sat Oct 01 2011 sander85 <sander85> 0-0.555.mga2
+ Revision: 150665
- fix bug #1443
- new version: 555

* Sat Apr 30 2011 sander85 <sander85> 0-0.549.mga1
+ Revision: 93728
- imported package unetbootin


* Sat Apr 30 2011 Sander Lepik <sander.lepik@eesti.ee> 0-0.549.mga1
- nev version 549
- clean spec
- add icons

* Fri Mar 19 2010 Thierry Vignaud <tv@mandriva.org> 0-0.393bzrmdv2010.1
+ Revision: 525268
- import unetbootin


* Fri Mar 19 2010 Thierry Vignaud <tvignaud@mandriva.com> 0-0.393bzrmdv2010.1
- initial import from fedora
- fix build on mandriva
